@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-24'; # DATE
 our $DIST = 'Log-ger-App'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our $DEBUG = defined($ENV{LOG_GER_APP_DEBUG}) ? $ENV{LOG_GER_APP_DEBUG} : 0;
 
@@ -126,7 +126,8 @@ sub import {
         );
         last if $olevel eq 'off';
         my $fmt =
-            ($ENV{LOG_ADD_LOCATION} ? '[file %F:%L] ': '').
+            ($ENV{LOG_ADD_STACK_TRACE} ? '[stack %T] ': '').
+            ($ENV{LOG_ADD_LOCATION} ? '[location %l] ': '').
             ($ENV{LOG_ADD_TIMESTAMP} ? '[%d] ': '').
             ($ENV{LOG_ADD_MEMORY_INFO} ? '[vmsize %_{vmsize}K] ': '').
             '%m';
@@ -223,7 +224,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -413,6 +414,12 @@ Boolean. Default to false. If set to true, will add location to the log:
 
  [file /some/path.pm:123]
 
+=head2 LOG_ADD_STACK_TRACE
+
+Boolean. Default to false. If set to true, will add stack trace to the log:
+
+ [stack ...]
+
 =head2 LOG_ADD_TIMESTAMP
 
 Boolean. Default to false. If set to true, will add timestamps to the screen
